@@ -14,16 +14,18 @@
 #    under the License.
 
 import logging
+import re
 
 import webob.dec
 import webob.exc
 
-from oslo_middleware._i18n import _LE
 from oslo_middleware import base
 
 
 LOG = logging.getLogger(__name__)
 
+_TOKEN_RE = re.compile(r'^(X-\w+-Token):.*$', flags=re.MULTILINE)
+
 
 class CatchErrors(base.ConfigurableMiddleware):
     """Middleware that provides high-level error handling.
@@ -37,7 +39,8 @@ class CatchErrors(base.ConfigurableMiddleware):
         try:
             response = req.get_response(self.application)
         except Exception:
-            LOG.exception(_LE('An error occurred during '
-                              'processing the request: %s'), req)
+            req_str = _TOKEN_RE.sub(r'\1: *****', req.as_text())
+            LOG.exception('An error occurred during '
+                          'processing the request: %s', req_str)
             response = webob.exc.HTTPInternalServerError()
         return response
