@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,7 +10,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 # implied. See the License for the specific language governing permissions and
 # limitations under the License.
-from debtcollector import removals
 from oslo_config import cfg
 from oslo_middleware import base
 
@@ -34,7 +32,7 @@ class HTTPProxyToWSGI(base.ConfigurableMiddleware):
     """
 
     def __init__(self, application, *args, **kwargs):
-        super(HTTPProxyToWSGI, self).__init__(application, *args, **kwargs)
+        super().__init__(application, *args, **kwargs)
         self.oslo_conf.register_opts(OPTS, group='oslo_middleware')
 
     @staticmethod
@@ -49,7 +47,7 @@ class HTTPProxyToWSGI(base.ConfigurableMiddleware):
             entry = {}
             for d in proxy.split(";"):
                 key, _, value = d.partition("=")
-                entry[key.lower()] = value
+                entry[key.lower().strip()] = value.strip()
             result.append(entry)
         return result
 
@@ -71,6 +69,10 @@ class HTTPProxyToWSGI(base.ConfigurableMiddleware):
                 if forwarded_host:
                     req.environ['HTTP_HOST'] = forwarded_host
 
+                forwarded_for = proxy.get("for")
+                if forwarded_for:
+                    req.environ['REMOTE_ADDR'] = forwarded_for
+
         else:
             # World before RFC7239
             forwarded_proto = req.environ.get("HTTP_X_FORWARDED_PROTO")
@@ -81,11 +83,10 @@ class HTTPProxyToWSGI(base.ConfigurableMiddleware):
             if forwarded_host:
                 req.environ['HTTP_HOST'] = forwarded_host
 
+            forwarded_for = req.environ.get("HTTP_X_FORWARDED_FOR")
+            if forwarded_for:
+                req.environ['REMOTE_ADDR'] = forwarded_for
+
         v = req.environ.get("HTTP_X_FORWARDED_PREFIX")
         if v:
             req.environ['SCRIPT_NAME'] = v + req.environ['SCRIPT_NAME']
-
-
-@removals.remove
-class HTTPProxyToWSGIMiddleware(HTTPProxyToWSGI):
-    """Placeholder for backward compatibility"""
